%global distributor_name mageia
%global distributor_version %{mageia}

# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{_libdir}/gnome-boxes/
%global __requires_exclude ^(%%(find %{buildroot}%{_libdir}/gnome-boxes/ -name '*.so' | xargs -n1 basename | sort -u | paste -s -d '|' -))

%global tarball_version %%(echo %{version} | tr '~' '.')
%global major_version %%(echo %%{tarball_version} | cut -d. -f1)

Name:		gnome-boxes
Version:	48.0
Release:	%mkrel 2
Summary:	A simple GNOME 3 application to access remote or virtual systems
Group:		Graphical desktop/GNOME
License:	LGPLv2+
URL:		https://wiki.gnome.org/Apps/Boxes
Source0:	https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{tarball_version}.tar.xz

BuildRequires:	meson
BuildRequires:	appstream
BuildRequires:	gettext >= 0.19.8
BuildRequires:	vala >= 0.36.0
BuildRequires:	vala-tools
BuildRequires:	yelp-tools
BuildRequires:	pkgconfig(vapigen)
BuildRequires:	pkgconfig(glib-2.0) >= 2.52
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(gtk+-3.0) >= 3.22.20
BuildRequires:	pkgconfig(gtksourceview-4)
BuildRequires:	pkgconfig(libportal)
BuildRequires:	pkgconfig(libportal-gtk3)
BuildRequires:	pkgconfig(gtk-vnc-2.0)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(libhandy-1)
BuildRequires:	pkgconfig(libvirt-gobject-1.0)
BuildRequires:	pkgconfig(libvirt-gconfig-1.0)
BuildRequires:	pkgconfig(spice-client-gtk-3.0) >= 0.12.101
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(libosinfo-1.0) >= 1.1.0
BuildRequires:	pkgconfig(libsoup-3.0)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(webkit2gtk-4.1)
BuildRequires:	itstool
BuildRequires:	libosinfo-vala
BuildRequires:	libxml2-utils
# b/c of: "Package `tracker-sparql-2.0' not found in specified Vala API directories or GObject-Introspection GIR directories"
BuildRequires:	tracker-vala
# Pulls in libvirtd + KVM, but no NAT / firewall configs
Requires:	libvirt-utils
Requires:	qemu-img
Requires:	qemu
# Needed for unattended installations
Requires:	mtools
Requires:	genisoimage
Requires:	adwaita-icon-theme
Provides:	bundled(libovf-glib)

# mga#33445
Requires: 	spice-gtk

%description
gnome-boxes lets you easily create, setup, access, and use:
* remote machines
* remote virtual machines
* local virtual machines
* When technology permits, set up access for applications on
  local virtual machines

%prep
%autosetup -p1 -n %{name}-%{tarball_version}

%build
%meson \
%if %{?distributor_name:1}%{!?distributor_name:0}
    -D distributor_name=%{distributor_name} \
%endif
%if 0%{?distributor_version}
    -D distributor_version=%{distributor_version} \
%endif
%meson_build

%install
%meson_install
%find_lang %{name} --with-gnome

# Remove unneeded development files
rm -rf %{buildroot}%{_includedir}/gnome-boxes/
rm -rf %{buildroot}%{_libdir}/gnome-boxes/girepository-1.0/
rm -rf %{buildroot}%{_libdir}/gnome-boxes/pkgconfig/
rm -rf %{buildroot}%{_datadir}/gnome-boxes/gir-1.0/
rm -rf %{buildroot}%{_datadir}/gnome-boxes/vapi/

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Boxes.desktop

%files -f %{name}.lang
%license COPYING copyright
%doc README.md NEWS
%{_bindir}/gnome-boxes
%{_libdir}/gnome-boxes
%{_libexecdir}/gnome-boxes-search-provider
%{_datadir}/applications/org.gnome.Boxes.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.boxes.gschema.xml
%{_datadir}/gnome-boxes/
%{_datadir}/gnome-shell/search-providers/org.gnome.Boxes.SearchProvider.ini
%{_iconsdir}/hicolor/*/apps/org.gnome.Boxes.svg
%{_iconsdir}/hicolor/symbolic/apps/org.gnome.Boxes-symbolic.svg
%{_datadir}/dbus-1/services/org.gnome.Boxes.SearchProvider.service
%{_datadir}/dbus-1/services/org.gnome.Boxes.service
%{_metainfodir}/org.gnome.Boxes.metainfo.xml


%changelog
* Thu Jun 12 2025 daviddavid <daviddavid> 48.0-2.mga10
+ Revision: 2190638
- drop unneeded clutter dependency

* Wed Mar 19 2025 daviddavid <daviddavid> 48.0-1.mga10
+ Revision: 2166711
- new version 48.0

* Sun Mar 16 2025 wally <wally> 47.0-3.mga10
+ Revision: 2164808
- rebuild for libxml2 2.13.6

* Mon Feb 17 2025 katnatek <katnatek> 47.0-2.mga10
+ Revision: 2149132
- require spice-gtk (mga#33445)

* Wed Sep 18 2024 daviddavid <daviddavid> 47.0-1.mga10
+ Revision: 2098447
- new version 47.0

* Sun Jun 02 2024 daviddavid <daviddavid> 46.1-1.mga10
+ Revision: 2069290
- new version 46.1

* Tue Mar 19 2024 daviddavid <daviddavid> 46.0-1.mga10
+ Revision: 2050878
- new version 46.0

* Sat Sep 30 2023 tv <tv> 45.0-1.mga10
+ Revision: 1992576
- Update to 42.0.1

* Sat Jun 03 2023 daviddavid <daviddavid> 44.2-1.mga9
+ Revision: 1960763
- new version 44.2

* Sun Apr 23 2023 ghibo <ghibo> 44.1-1.mga9
+ Revision: 1954612
- Update to release 44.1

* Fri Apr 21 2023 tmb <tmb> 44.0-1.mga9
+ Revision: 1953911
- update to 44.0

* Sun Jan 01 2023 ghibo <ghibo> 43.2-1.mga9
+ Revision: 1928723
- Update to release 43.2

* Wed Oct 26 2022 ovitters <ovitters> 43.1-1.mga9
+ Revision: 1899492
- new version 43.1

* Sun Sep 18 2022 wally <wally> 43.0-1.mga9
+ Revision: 1890089
- new version 43.0

* Thu Jul 07 2022 ovitters <ovitters> 42.3-1.mga9
+ Revision: 1867902
- new version 42.3

* Fri Jul 01 2022 ovitters <ovitters> 42.2-1.mga9
+ Revision: 1866959
- new version 42.2

* Mon May 30 2022 ovitters <ovitters> 42.1-1.mga9
+ Revision: 1860756
- new version 42.1

* Sat Mar 26 2022 tv <tv> 42.0.1-1.mga9
+ Revision: 1828042
- Update to 42.0.1

* Wed Mar 16 2022 tv <tv> 42~rc-1.mga9
+ Revision: 1794628
- Update to 42.rc

* Mon Jan 10 2022 tv <tv> 41.3-1.mga9
+ Revision: 1767679
- 41.3

* Fri Jul 09 2021 ovitters <ovitters> 40.3-1.mga9
+ Revision: 1735329
- new version 40.3

* Fri Jun 04 2021 ovitters <ovitters> 40.2-1.mga9
+ Revision: 1729702
- new version 40.2

* Wed May 05 2021 ovitters <ovitters> 40.1-1.mga9
+ Revision: 1721482
- new version 40.1

* Sat Mar 27 2021 tv <tv> 40.0-1.mga9
+ Revision: 1710909
- 40.0

* Mon Nov 23 2020 daviddavid <daviddavid> 3.38.2-2.mga8
+ Revision: 1648681
- use system libhandy and port to libhandy-1

* Mon Nov 23 2020 ovitters <ovitters> 3.38.2-1.mga8
+ Revision: 1648668
- new version 3.38.2

* Tue Oct 06 2020 ovitters <ovitters> 3.38.1-1.mga8
+ Revision: 1632427
- new version 3.38.1
- drop merged patch gnome-boxes-tracker3.patch

* Fri Sep 11 2020 ovitters <ovitters> 3.38.0-1.mga8
+ Revision: 1624540
- new version 3.38.0

* Fri Sep 11 2020 tv <tv> 3.37.91-1.mga8
+ Revision: 1624376
- Switch to tracker3
+ ovitters <ovitters>
- new version 3.37.91

* Wed Aug 12 2020 tv <tv> 3.37.90-1.mga8
+ Revision: 1613468
- BR pkgconfig(gtksourceview-4)
+ ovitters <ovitters>
- new version 3.37.90
+ martinw <martinw>
- rebuild for new libhandy

* Wed Jun 10 2020 ovitters <ovitters> 3.37.1-1.mga8
+ Revision: 1591724
- new version 3.37.1

* Mon May 25 2020 ovitters <ovitters> 3.36.4-1.mga8
+ Revision: 1587618
- new version 3.36.4

* Mon Apr 20 2020 ovitters <ovitters> 3.36.3-1.mga8
+ Revision: 1570018
- new version 3.36.3

* Mon Mar 30 2020 ovitters <ovitters> 3.36.2-1.mga8
+ Revision: 1562439
- new version 3.36.2

* Tue Mar 17 2020 ovitters <ovitters> 3.36.1-1.mga8
+ Revision: 1557491
- new version 3.36.1

* Fri Mar 06 2020 ovitters <ovitters> 3.36.0-1.mga8
+ Revision: 1554405
- new version 3.36.0
+ tv <tv>
- try to build w/o the map cpu trick

* Mon Mar 02 2020 tv <tv> 3.35.91-2.mga8
+ Revision: 1553007
- Remove unneeded development files

* Mon Mar 02 2020 ovitters <ovitters> 3.35.91-1.mga8
+ Revision: 1552929
- new version 3.35.91

* Mon Feb 24 2020 tv <tv> 3.35.90-1.mga8
+ Revision: 1549837
- 3.35.90

* Wed Feb 19 2020 umeabot <umeabot> 3.34.4-2.mga8
+ Revision: 1542745
- Mageia 8 Mass Rebuild

* Tue Feb 18 2020 ovitters <ovitters> 3.34.4-1.mga8
+ Revision: 1541100
- new version 3.34.4

* Mon Jan 06 2020 ovitters <ovitters> 3.34.3-1.mga8
+ Revision: 1476988
- new version 3.34.3

* Fri Nov 29 2019 tv <tv> 3.34.2-2.mga8
+ Revision: 1463791
- rebuild for new libosinfo

* Sat Nov 23 2019 ovitters <ovitters> 3.34.2-1.mga8
+ Revision: 1462482
- new version 3.34.2

* Mon Oct 07 2019 ovitters <ovitters> 3.34.1-1.mga8
+ Revision: 1450299
- new version 3.34.1

* Mon Sep 09 2019 ovitters <ovitters> 3.34.0-1.mga8
+ Revision: 1438915
- new version 3.34.0

* Wed Aug 14 2019 ovitters <ovitters> 3.33.90-1.mga8
+ Revision: 1429304
- new version 3.33.90

* Fri Aug 09 2019 tv <tv> 3.33.3-1.mga8
+ Revision: 1428286
- new release

* Fri May 10 2019 daviddavid <daviddavid> 3.32.1-1.mga7
+ Revision: 1397000
- new version 3.32.1

* Wed Apr 17 2019 umeabot <umeabot> 3.32.0.2-2.mga7
+ Revision: 1392270
- Rebuild with meson 0.50.1

* Fri Mar 29 2019 ovitters <ovitters> 3.32.0.2-1.mga7
+ Revision: 1381088
- new version 3.32.0.2

* Mon Mar 18 2019 ovitters <ovitters> 3.32.0.1-1.mga7
+ Revision: 1378584
- new version 3.32.0.1

* Mon Mar 11 2019 ovitters <ovitters> 3.32.0-1.mga7
+ Revision: 1374099
- new version 3.32.0

* Sat Mar 09 2019 daviddavid <daviddavid> 3.31.91-1.mga7
+ Revision: 1373076
- new version 3.31.91

* Thu Nov 22 2018 ovitters <ovitters> 3.30.3-1.mga7
+ Revision: 1333361
- new version 3.30.3

* Wed Oct 24 2018 ovitters <ovitters> 3.30.2-1.mga7
+ Revision: 1325022
- new version 3.30.2

* Tue Sep 25 2018 ovitters <ovitters> 3.30.1-1.mga7
+ Revision: 1304812
- new version 3.30.1

* Tue Sep 04 2018 tv <tv> 3.30.0-1.mga7
+ Revision: 1256937
- adjust filelist
+ ovitters <ovitters>
- new version 3.30.0

* Tue Aug 28 2018 ovitters <ovitters> 3.29.92-1.mga7
+ Revision: 1255229
- new version 3.29.92

* Mon Aug 13 2018 tv <tv> 3.29.91-1.mga7
+ Revision: 1251397
- set _smp_ncpus_max to 4 in order to fix build on BS
+ ovitters <ovitters>
- new version 3.29.91

* Fri Aug 10 2018 guillomovitch <guillomovitch> 3.29.4-1.mga7
+ Revision: 1250886
- fix files list
+ ovitters <ovitters>
- new version 3.29.4
- new version 3.29.3

* Tue Jul 03 2018 tv <tv> 3.28.5-1.mga7
+ Revision: 1241451
- fix filelist
+ ovitters <ovitters>
- new version 3.28.5
- dropped merged patch gnome-boxes-3.26.1-use-virtio.patch

* Wed May 09 2018 ovitters <ovitters> 3.28.4-1.mga7
+ Revision: 1227890
- new version 3.28.4

* Mon May 07 2018 ovitters <ovitters> 3.28.3-1.mga7
+ Revision: 1226967
- new version 3.28.3

* Tue Apr 10 2018 ovitters <ovitters> 3.28.2-1.mga7
+ Revision: 1217008
- new version 3.28.2

* Mon Apr 09 2018 ovitters <ovitters> 3.28.1-1.mga7
+ Revision: 1216550
- new version 3.28.1

* Mon Apr 02 2018 tv <tv> 3.28.0-1.mga7
+ Revision: 1214593
- new release (got from https://gitlab.gnome.org/GNOME/gnome-boxes/tags/v3.28.0)
  (as no proper release was done)
- BR libosinfo-vala
- add %%check
- fix URL
- fix license
- wrap too long description

* Tue Mar 13 2018 tv <tv> 3.27.92-1.mga7
+ Revision: 1208881
- needs genisoimage instead of fuseiso
- BR tracker-vala
- define vendor version
- package license
- BR json-glib-1.0 & libusb-1.0
- bump needed versions
- use virtio by default rather than QXL
- BR pkgconfig(govirt-1.0)
- switch to meson
+ ovitters <ovitters>
- new version 3.27.92

* Tue Feb 20 2018 ovitters <ovitters> 3.27.90-1.mga7
+ Revision: 1203703
- new version 3.27.90

* Mon Oct 30 2017 ovitters <ovitters> 3.26.2-1.mga7
+ Revision: 1174980
- new version 3.26.2

* Mon Oct 02 2017 ovitters <ovitters> 3.26.1-1.mga7
+ Revision: 1162707
- new version 3.26.1

* Thu Sep 21 2017 tv <tv> 3.26.0-2.mga7
+ Revision: 1156850
- rebuild against new tracker

* Wed Sep 20 2017 tv <tv> 3.26.0-1.mga7
+ Revision: 1156327
- new release

* Wed Mar 22 2017 ovitters <ovitters> 3.24.0-1.mga6
+ Revision: 1094326
- new version 3.24.0

* Mon Feb 06 2017 ovitters <ovitters> 3.22.4-1.mga6
+ Revision: 1085014
- new version 3.22.4

* Fri Dec 23 2016 daviddavid <daviddavid> 3.22.3-2.mga6
+ Revision: 1076518
- rebuild for new spice-gtk 0.33

* Mon Nov 21 2016 ovitters <ovitters> 3.22.3-1.mga6
+ Revision: 1068576
- new version 3.22.3

* Sat Nov 05 2016 ovitters <ovitters> 3.22.2-1.mga6
+ Revision: 1065457
- new version 3.22.2

* Fri Oct 07 2016 ovitters <ovitters> 3.22.1-1.mga6
+ Revision: 1059325
- new version 3.22.1

* Wed Sep 21 2016 ovitters <ovitters> 3.22.0-1.mga6
+ Revision: 1055019
- new version 3.22.0

* Mon May 09 2016 ovitters <ovitters> 3.20.2-1.mga6
+ Revision: 1011548
- new version 3.20.2

* Tue Mar 22 2016 ovitters <ovitters> 3.20.0-1.mga6
+ Revision: 994106
- new version 3.20.0

* Wed Mar 16 2016 ovitters <ovitters> 3.19.92-1.mga6
+ Revision: 992164
- new version 3.19.92

* Thu Mar 03 2016 ovitters <ovitters> 3.19.91-1.mga6
+ Revision: 983840
- new version 3.19.91

* Mon Jan 18 2016 ovitters <ovitters> 3.19.4-1.mga6
+ Revision: 925503
- new version 3.19.4
- new version 3.19.3
+ tv <tv>
- bump req on libvirt-gobject-1.0

* Mon Nov 23 2015 ovitters <ovitters> 3.19.1-1.mga6
+ Revision: 905155
- new version 3.19.1

* Mon Oct 12 2015 ovitters <ovitters> 3.18.1-1.mga6
+ Revision: 890093
- new version 3.18.1

* Thu Sep 24 2015 tv <tv> 3.18.0-1.mga6
+ Revision: 882838
- new release

* Tue Sep 01 2015 ovitters <ovitters> 3.17.91-1.mga6
+ Revision: 872123
- new version 3.17.91

* Tue Aug 18 2015 ovitters <ovitters> 3.17.90-1.mga6
+ Revision: 865787
- new version 3.17.90
- new version 3.17.4

* Wed Jun 24 2015 ovitters <ovitters> 3.17.3-1.mga6
+ Revision: 842244
- new version 3.17.3

* Mon Jun 22 2015 ovitters <ovitters> 3.17.2-1.mga6
+ Revision: 839763
- new version 3.17.2

* Sat Jun 20 2015 ovitters <ovitters> 3.14.3.1-1.mga6
+ Revision: 836428
- new version 3.14.3.1

* Wed Nov 12 2014 ovitters <ovitters> 3.14.2-1.mga5
+ Revision: 796552
- new version 3.14.2

* Wed Oct 15 2014 ovitters <ovitters> 3.14.1.1-1.mga5
+ Revision: 757164
- new version 3.14.1.1
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Mon Oct 13 2014 ovitters <ovitters> 3.14.1-1.mga5
+ Revision: 738311
- new version 3.14.1

* Sun Sep 28 2014 ovitters <ovitters> 3.14.0-1.mga5
+ Revision: 731352
- new version 3.14.0

* Tue Sep 16 2014 umeabot <umeabot> 3.13.92-2.mga5
+ Revision: 679701
- Mageia 5 Mass Rebuild

* Tue Sep 16 2014 ovitters <ovitters> 3.13.92-1.mga5
+ Revision: 677585
- new version 3.13.92

* Tue Sep 02 2014 ovitters <ovitters> 3.13.91-1.mga5
+ Revision: 670970
- new version 3.13.91
- dropped merged patch 1

* Wed Aug 27 2014 pterjan <pterjan> 3.13.90-1.mga5
+ Revision: 668812
- Add missing BuildRequires for help
- Update libosinfo BuildRequires to the one really needed
- Add upstream patch fixing the build
+ ovitters <ovitters>
- new version 3.13.90

* Mon Jul 21 2014 ovitters <ovitters> 3.13.4-1.mga5
+ Revision: 655250
- new version 3.13.4

* Tue Jun 24 2014 ovitters <ovitters> 3.13.3-1.mga5
+ Revision: 639398
- new version 3.13.3

* Tue Jun 24 2014 ovitters <ovitters> 3.12.3-1.mga5
+ Revision: 639362
- new version 3.12.3

* Tue May 13 2014 ovitters <ovitters> 3.12.2-1.mga5
+ Revision: 622492
- new version 3.12.2
+ wally <wally>
- require adwaita-icon-theme instead of obsolete gnome-icon-theme

* Tue Apr 15 2014 ovitters <ovitters> 3.12.1-1.mga5
+ Revision: 615146
- new version 3.12.1

* Mon Mar 24 2014 ovitters <ovitters> 3.12.0-1.mga5
+ Revision: 608001
- new version 3.12.0

* Tue Mar 18 2014 ovitters <ovitters> 3.11.92-1.mga5
+ Revision: 605213
- new version 3.11.92

* Tue Mar 04 2014 ovitters <ovitters> 3.11.91-1.mga5
+ Revision: 599541
- new version 3.11.91

* Wed Feb 19 2014 dams <dams> 3.11.90.1-2.mga5
+ Revision: 594771
- rebuild for new tracker

* Tue Feb 18 2014 ovitters <ovitters> 3.11.90.1-1.mga5
+ Revision: 594529
- new version 3.11.90.1

* Mon Feb 17 2014 ovitters <ovitters> 3.11.90-1.mga5
+ Revision: 594038
- new version 3.11.90

* Thu Feb 06 2014 dams <dams> 3.11.5.1-1.mga5
+ Revision: 584022
- new version 3.11.5.1

* Wed Nov 20 2013 ovitters <ovitters> 3.10.2-1.mga4
+ Revision: 551978
- new version 3.10.2

* Sat Nov 09 2013 ovitters <ovitters> 3.10.0-3.mga4
+ Revision: 550156
- fix url

* Sat Oct 19 2013 umeabot <umeabot> 3.10.0-2.mga4
+ Revision: 536434
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 ovitters <ovitters> 3.10.0-1.mga4
+ Revision: 484279
- new version 3.10.0

* Tue Sep 17 2013 ovitters <ovitters> 3.9.92-1.mga4
+ Revision: 480892
- new version 3.9.92

* Wed Sep 04 2013 ovitters <ovitters> 3.9.91.1-1.mga4
+ Revision: 475195
- new version 3.9.91.1

* Tue Sep 03 2013 fwang <fwang> 3.9.91-1.mga4
+ Revision: 474554
- update file list
+ ovitters <ovitters>
- new version 3.9.91

* Tue Aug 20 2013 ovitters <ovitters> 3.9.90-1.mga4
+ Revision: 468318
- new version 3.9.90

* Mon Jul 29 2013 ovitters <ovitters> 3.9.5-1.mga4
+ Revision: 460517
- new version 3.9.5

* Fri Jul 26 2013 dams <dams> 3.9.3-1.mga4
+ Revision: 458365
- new version 3.9.3

* Sun Jul 14 2013 sander85 <sander85> 3.8.3-2.mga4
+ Revision: 454288
- Rebuild for new cogl

* Tue May 28 2013 ovitters <ovitters> 3.8.3-1.mga4
+ Revision: 429406
- new version 3.8.3

* Sat May 25 2013 blino <blino> 3.8.2-1.mga4
+ Revision: 427687
- update libvirt requirements
- buildrequire tracker-sparql-0.16 (not 0.14)
- buildrequire libosinfo >= 0.2.6
+ ovitters <ovitters>
- br itstool,libxml2-utils
- new version 3.8.2

* Mon Jan 14 2013 ovitters <ovitters> 3.6.3-1.mga3
+ Revision: 388098
- new version 3.6.3

* Sat Jan 12 2013 umeabot <umeabot> 3.6.2-2.mga3
+ Revision: 352059
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 13 2012 fwang <fwang> 3.6.2-1.mga3
+ Revision: 317460
- new version 3.6.2

* Tue Oct 16 2012 ovitters <ovitters> 3.6.1.1-1.mga3
+ Revision: 307300
- br libsoup-2.4
- new version 3.6.1.1
- new version 3.6.1

* Tue Sep 25 2012 ovitters <ovitters> 3.6.0-1.mga3
+ Revision: 297513
- new version 3.6.0

* Wed Sep 19 2012 ovitters <ovitters> 3.5.92-1.mga3
+ Revision: 296172
- new version 3.5.92

* Tue Sep 11 2012 ovitters <ovitters> 3.5.91-2.mga3
+ Revision: 292443
- update br
- rebuild; only src rpm was available

* Mon Sep 03 2012 ovitters <ovitters> 3.5.91-1.mga3
+ Revision: 287744
- new version 3.5.91

* Wed Aug 29 2012 fwang <fwang> 3.5.90-1.mga3
+ Revision: 285503
- update file list
- tweak vala br
+ ovitters <ovitters>
- br pkgconfig(uuid)
- new version 3.5.90

* Thu Aug 09 2012 ovitters <ovitters> 3.5.5-1.mga3
+ Revision: 280307
- update br
- new version 3.5.5

* Mon Jul 16 2012 ovitters <ovitters> 3.5.4.1-1.mga3
+ Revision: 271426
- new version 3.5.4.1
- new version 3.5.4

* Tue Jul 03 2012 ovitters <ovitters> 3.5.3-2.mga3
+ Revision: 266988
- improve summary and description (thanks fedora:P)

* Wed Jun 27 2012 ovitters <ovitters> 3.5.3-1.mga3
+ Revision: 264573
- update br
- br clutter-1.0
- new version 3.5.3

* Sat Jun 09 2012 ovitters <ovitters> 3.4.3-1.mga3
+ Revision: 258997
- new version 3.4.3

* Tue May 29 2012 ovitters <ovitters> 3.4.2-1.mga3
+ Revision: 249211
- update buildrequires
- new version 3.4.2
- new version 3.4.1

* Sun Apr 01 2012 ovitters <ovitters> 3.4.0.1-1.mga2
+ Revision: 227703
- update buildrequires
- new version 3.4.0.1

* Mon Mar 26 2012 ovitters <ovitters> 3.4.0-1.mga2
+ Revision: 226704
- new version 3.4.0

* Tue Mar 20 2012 ovitters <ovitters> 3.3.92-1.mga2
+ Revision: 225070
- new version 3.3.92

* Tue Mar 06 2012 fwang <fwang> 3.3.91-1.mga2
+ Revision: 219680
- bump req
- new version 3.3.91

* Thu Feb 23 2012 tv <tv> 3.3.90-2.mga2
+ Revision: 213165
- rebuild for new cogl
+ fwang <fwang>
- fix br
- new version 3.3.90

* Wed Feb 08 2012 ovitters <ovitters> 3.3.5.1-1.mga2
+ Revision: 206537
- new version

* Wed Feb 08 2012 ovitters <ovitters> 3.3.5-1.mga2
+ Revision: 206511
- explicitly enable vala
- fix compilation using upstream instructions
- fix buildrequires
- new version

* Wed Jan 25 2012 ovitters <ovitters> 3.3.4.1-1.mga2
+ Revision: 201488
- new version

* Tue Jan 17 2012 fwang <fwang> 3.3.4-2.mga2
+ Revision: 197341
- rebuild for new cogl

* Mon Jan 16 2012 ovitters <ovitters> 3.3.4-1.mga2
+ Revision: 197018
- fix buildrequires
- new version

* Wed Jan 11 2012 ovitters <ovitters> 3.3.3-5.mga2
+ Revision: 194853
- fix requires

* Tue Jan 10 2012 ovitters <ovitters> 3.3.3-4.mga2
+ Revision: 194472
- even more requires

* Tue Jan 10 2012 ovitters <ovitters> 3.3.3-3.mga2
+ Revision: 194465
- fix more requires (thanks to Michael Hill)

* Tue Jan 10 2012 ovitters <ovitters> 3.3.3-2.mga2
+ Revision: 194464
- fix requires (thanks to Michael Hill)

* Wed Dec 21 2011 ovitters <ovitters> 3.3.3-1.mga2
+ Revision: 185369
- new version 3.3.3

* Thu Dec 01 2011 ovitters <ovitters> 3.3.2-2.mga2
+ Revision: 175024
- fix URL

* Thu Dec 01 2011 ovitters <ovitters> 3.3.2-1.mga2
+ Revision: 174969
- fix MimeType in desktop file
- Unity is not in .desktop file, no need to remove
- imported package gnome-boxes

